@@ -7,11 +7,15 @@
 
 /* .C calls */
 extern void hellcorC(double *x, int *xlen, double *statistic, int *pvalcomp,
-		     double *pvalue, int *KLmaxvalue, double *alphavalue);
+		     double *pvalue, int *Kmaxvalue, int *Lmaxvalue,
+		     int *Kset, int *Lset, double *alphavalue,
+		     double *conflevel, int *B1, int *B2, double *CIetaleft, double *CIetaright);
 
+extern void hilbertpeano(double *x, int *xlen, int *depth, int *setseed);
 
 static const R_CMethodDef CEntries[] = {
-    {"hellcorC", (DL_FUNC) &hellcorC, 7},
+    {"hellcorC", (DL_FUNC) &hellcorC, 15},
+    {"hilbertpeano", (DL_FUNC) &hilbertpeano, 4},
     {NULL, NULL, 0}
 };
 
